==> ejc-scientific-impl-3.0.0-20250418.081255-74-sources.jar: com/ejianc/business/scientific/sci/bean/SciProjectBudgetYearEntity.java <==
package com.ejianc.business.scientific.sci.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 科研项目立项-经费预算-年度预算
 * 
 * @author generator
 * 
 */
 @TableName("ejc_scientific_project_budget_year")
public class SciProjectBudgetYearEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pid")
    private Long pid; // 主表主键
    @TableField(value="fee_id")
    private Long feeId; // 费用类型主键
    @TableField(value="fee_name")
    private String feeName; // 费用类型名称
    @TableField(value="budget_mny")
    private BigDecimal budgetMny; // 预算金额
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="source_id")
    private Long sourceId; // 来源主键
    @TableField(value="plan_year")
    private String planYear; // 年度
    
    
    

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public Long getFeeId() {
        return feeId;
    }

    public void setFeeId(Long feeId) {
        this.feeId = feeId;
    }
    public String getFeeName() {
        return feeName;
    }

    public void setFeeName(String feeName) {
        this.feeName = feeName;
    }
    public BigDecimal getBudgetMny() {
        return budgetMny;
    }

    public void setBudgetMny(BigDecimal budgetMny) {
        this.budgetMny = budgetMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public String getPlanYear() {
        return planYear;
    }

    public void setPlanYear(String planYear) {
        this.planYear = planYear;
    }
    
}

==> ejc-scientific-impl-3.0.0-20250828.124943-89-sources.jar: com/ejianc/business/scientific/sci/bean/SciProjectBudgetYearEntity.java <==
package com.ejianc.business.scientific.sci.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 科研项目立项-经费预算-年度预算
 * 
 * @author generator
 * 
 */
 @TableName("ejc_scientific_project_budget_year")
public class SciProjectBudgetYearEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pid")
    private Long pid; // 主表主键
    @TableField(value="fee_id")
    private Long feeId; // 费用类型主键
    @TableField(value="fee_name")
    private String feeName; // 费用类型名称
    @TableField(value="budget_mny")
    private BigDecimal budgetMny; // 预算金额
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="source_id")
    private Long sourceId; // 来源主键
    @TableField(value="plan_year")
    private String planYear; // 年度
    @TableField(value = "total_hours")
    private BigDecimal totalHours;

    public BigDecimal getTotalHours() {
        return totalHours;
    }

    public void setTotalHours(BigDecimal totalHours) {
        this.totalHours = totalHours;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public Long getFeeId() {
        return feeId;
    }

    public void setFeeId(Long feeId) {
        this.feeId = feeId;
    }
    public String getFeeName() {
        return feeName;
    }

    public void setFeeName(String feeName) {
        this.feeName = feeName;
    }
    public BigDecimal getBudgetMny() {
        return budgetMny;
    }

    public void setBudgetMny(BigDecimal budgetMny) {
        this.budgetMny = budgetMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public String getPlanYear() {
        return planYear;
    }

    public void setPlanYear(String planYear) {
        this.planYear = planYear;
    }
    
}
